@@ -3,18 +3,21 @@ Main interface for appconfig service type definitions.
 
 Usage::
 
-    from mypy_boto3.appconfig.type_defs import ApplicationTypeDef
+    ```python
+    from mypy_boto3_appconfig.type_defs import ApplicationTypeDef
 
     data: ApplicationTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from datetime import datetime
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -23,21 +26,24 @@ else:
 
 __all__ = (
     "ApplicationTypeDef",
-    "ApplicationsTypeDef",
-    "ValidatorTypeDef",
-    "ConfigurationProfileTypeDef",
     "ConfigurationProfileSummaryTypeDef",
+    "DeploymentEventTypeDef",
+    "DeploymentStrategyTypeDef",
+    "DeploymentSummaryTypeDef",
+    "EnvironmentTypeDef",
+    "HostedConfigurationVersionSummaryTypeDef",
+    "MonitorTypeDef",
+    "ValidatorTypeDef",
+    "ApplicationsTypeDef",
+    "ConfigurationProfileTypeDef",
     "ConfigurationProfilesTypeDef",
     "ConfigurationTypeDef",
-    "DeploymentStrategyTypeDef",
     "DeploymentStrategiesTypeDef",
-    "DeploymentEventTypeDef",
     "DeploymentTypeDef",
-    "DeploymentSummaryTypeDef",
     "DeploymentsTypeDef",
-    "MonitorTypeDef",
-    "EnvironmentTypeDef",
     "EnvironmentsTypeDef",
+    "HostedConfigurationVersionTypeDef",
+    "HostedConfigurationVersionsTypeDef",
     "ResourceTagsTypeDef",
 )
 
@@ -45,28 +51,6 @@ ApplicationTypeDef = TypedDict(
     "ApplicationTypeDef", {"Id": str, "Name": str, "Description": str}, total=False
 )
 
-ApplicationsTypeDef = TypedDict(
-    "ApplicationsTypeDef", {"Items": List[ApplicationTypeDef], "NextToken": str}, total=False
-)
-
-ValidatorTypeDef = TypedDict(
-    "ValidatorTypeDef", {"Type": Literal["JSON_SCHEMA", "LAMBDA"], "Content": str}
-)
-
-ConfigurationProfileTypeDef = TypedDict(
-    "ConfigurationProfileTypeDef",
-    {
-        "ApplicationId": str,
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "LocationUri": str,
-        "RetrievalRoleArn": str,
-        "Validators": List[ValidatorTypeDef],
-    },
-    total=False,
-)
-
 ConfigurationProfileSummaryTypeDef = TypedDict(
     "ConfigurationProfileSummaryTypeDef",
     {
@@ -79,39 +63,6 @@ ConfigurationProfileSummaryTypeDef = TypedDict(
     total=False,
 )
 
-ConfigurationProfilesTypeDef = TypedDict(
-    "ConfigurationProfilesTypeDef",
-    {"Items": List[ConfigurationProfileSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-ConfigurationTypeDef = TypedDict(
-    "ConfigurationTypeDef",
-    {"Content": Union[bytes, IO], "ConfigurationVersion": str, "ContentType": str},
-    total=False,
-)
-
-DeploymentStrategyTypeDef = TypedDict(
-    "DeploymentStrategyTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "DeploymentDurationInMinutes": int,
-        "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
-        "GrowthFactor": float,
-        "FinalBakeTimeInMinutes": int,
-        "ReplicateTo": Literal["NONE", "SSM_DOCUMENT"],
-    },
-    total=False,
-)
-
-DeploymentStrategiesTypeDef = TypedDict(
-    "DeploymentStrategiesTypeDef",
-    {"Items": List[DeploymentStrategyTypeDef], "NextToken": str},
-    total=False,
-)
-
 DeploymentEventTypeDef = TypedDict(
     "DeploymentEventTypeDef",
     {
@@ -130,29 +81,17 @@ DeploymentEventTypeDef = TypedDict(
     total=False,
 )
 
-DeploymentTypeDef = TypedDict(
-    "DeploymentTypeDef",
+DeploymentStrategyTypeDef = TypedDict(
+    "DeploymentStrategyTypeDef",
     {
-        "ApplicationId": str,
-        "EnvironmentId": str,
-        "DeploymentStrategyId": str,
-        "ConfigurationProfileId": str,
-        "DeploymentNumber": int,
-        "ConfigurationName": str,
-        "ConfigurationLocationUri": str,
-        "ConfigurationVersion": str,
+        "Id": str,
+        "Name": str,
         "Description": str,
         "DeploymentDurationInMinutes": int,
         "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
         "GrowthFactor": float,
         "FinalBakeTimeInMinutes": int,
-        "State": Literal[
-            "BAKING", "VALIDATING", "DEPLOYING", "COMPLETE", "ROLLING_BACK", "ROLLED_BACK"
-        ],
-        "EventLog": List[DeploymentEventTypeDef],
-        "PercentageComplete": float,
-        "StartedAt": datetime,
-        "CompletedAt": datetime,
+        "ReplicateTo": Literal["NONE", "SSM_DOCUMENT"],
     },
     total=False,
 )
@@ -177,12 +116,6 @@ DeploymentSummaryTypeDef = TypedDict(
     total=False,
 )
 
-DeploymentsTypeDef = TypedDict(
-    "DeploymentsTypeDef", {"Items": List[DeploymentSummaryTypeDef], "NextToken": str}, total=False
-)
-
-MonitorTypeDef = TypedDict("MonitorTypeDef", {"AlarmArn": str, "AlarmRoleArn": str}, total=False)
-
 EnvironmentTypeDef = TypedDict(
     "EnvironmentTypeDef",
     {
@@ -191,13 +124,117 @@ EnvironmentTypeDef = TypedDict(
         "Name": str,
         "Description": str,
         "State": Literal["READY_FOR_DEPLOYMENT", "DEPLOYING", "ROLLING_BACK", "ROLLED_BACK"],
-        "Monitors": List[MonitorTypeDef],
+        "Monitors": List["MonitorTypeDef"],
     },
     total=False,
 )
 
+HostedConfigurationVersionSummaryTypeDef = TypedDict(
+    "HostedConfigurationVersionSummaryTypeDef",
+    {
+        "ApplicationId": str,
+        "ConfigurationProfileId": str,
+        "VersionNumber": int,
+        "Description": str,
+        "ContentType": str,
+    },
+    total=False,
+)
+
+MonitorTypeDef = TypedDict("MonitorTypeDef", {"AlarmArn": str, "AlarmRoleArn": str}, total=False)
+
+ValidatorTypeDef = TypedDict(
+    "ValidatorTypeDef", {"Type": Literal["JSON_SCHEMA", "LAMBDA"], "Content": str}
+)
+
+ApplicationsTypeDef = TypedDict(
+    "ApplicationsTypeDef", {"Items": List["ApplicationTypeDef"], "NextToken": str}, total=False
+)
+
+ConfigurationProfileTypeDef = TypedDict(
+    "ConfigurationProfileTypeDef",
+    {
+        "ApplicationId": str,
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "LocationUri": str,
+        "RetrievalRoleArn": str,
+        "Validators": List["ValidatorTypeDef"],
+    },
+    total=False,
+)
+
+ConfigurationProfilesTypeDef = TypedDict(
+    "ConfigurationProfilesTypeDef",
+    {"Items": List["ConfigurationProfileSummaryTypeDef"], "NextToken": str},
+    total=False,
+)
+
+ConfigurationTypeDef = TypedDict(
+    "ConfigurationTypeDef",
+    {"Content": bytes, "ConfigurationVersion": str, "ContentType": str},
+    total=False,
+)
+
+DeploymentStrategiesTypeDef = TypedDict(
+    "DeploymentStrategiesTypeDef",
+    {"Items": List["DeploymentStrategyTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DeploymentTypeDef = TypedDict(
+    "DeploymentTypeDef",
+    {
+        "ApplicationId": str,
+        "EnvironmentId": str,
+        "DeploymentStrategyId": str,
+        "ConfigurationProfileId": str,
+        "DeploymentNumber": int,
+        "ConfigurationName": str,
+        "ConfigurationLocationUri": str,
+        "ConfigurationVersion": str,
+        "Description": str,
+        "DeploymentDurationInMinutes": int,
+        "GrowthType": Literal["LINEAR", "EXPONENTIAL"],
+        "GrowthFactor": float,
+        "FinalBakeTimeInMinutes": int,
+        "State": Literal[
+            "BAKING", "VALIDATING", "DEPLOYING", "COMPLETE", "ROLLING_BACK", "ROLLED_BACK"
+        ],
+        "EventLog": List["DeploymentEventTypeDef"],
+        "PercentageComplete": float,
+        "StartedAt": datetime,
+        "CompletedAt": datetime,
+    },
+    total=False,
+)
+
+DeploymentsTypeDef = TypedDict(
+    "DeploymentsTypeDef", {"Items": List["DeploymentSummaryTypeDef"], "NextToken": str}, total=False
+)
+
 EnvironmentsTypeDef = TypedDict(
-    "EnvironmentsTypeDef", {"Items": List[EnvironmentTypeDef], "NextToken": str}, total=False
+    "EnvironmentsTypeDef", {"Items": List["EnvironmentTypeDef"], "NextToken": str}, total=False
+)
+
+HostedConfigurationVersionTypeDef = TypedDict(
+    "HostedConfigurationVersionTypeDef",
+    {
+        "ApplicationId": str,
+        "ConfigurationProfileId": str,
+        "VersionNumber": int,
+        "Description": str,
+        "Content": bytes,
+        "ContentType": str,
+    },
+    total=False,
+)
+
+HostedConfigurationVersionsTypeDef = TypedDict(
+    "HostedConfigurationVersionsTypeDef",
+    {"Items": List["HostedConfigurationVersionSummaryTypeDef"], "NextToken": str},
+    total=False,
 )
 
 ResourceTagsTypeDef = TypedDict("ResourceTagsTypeDef", {"Tags": Dict[str, str]}, total=False)
